Overview
========

wnnet is a python package for handling
`webnucleo <http://webnucleo.org/>`_ reaction networks.

Installation
------------

Install from `PyPI <https://pypi.org/project/wnnet>`_ with pip by
typing in your favorite terminal::

    $ pip install wnnet

Authors
-------

- Bradley S. Meyer <mbradle@g.clemson.edu>
- Mengke Li <mengkel@g.clemson.edu>

Contribute
----------

- Issue Tracker: `<https://github.com/mbradle/wnnet/issues/>`_
- Source Code: `<https://github.com/mbradle/wnnet/>`_

License
-------

The project is licensed under the GNU Public License v3 (or later).

Documentation
-------------

The project documentation is available at `<https://wnnet.readthedocs.io>`_.

Usage
-----

The best way to get started using wnnet is to follow the
`tutorial <https://github.com/mbradle/wnnet/tree/main/tutorial>`_.
